@@ -15,16 +15,14 @@ class Virtualenv:
         return self.domain == other.domain and self.python_version == other.python_version
 
     def create(self, nuke):
-        print(snakesay("Creating virtualenv with Python{python_version}".format(python_version=self.python_version)))
-        command = "mkvirtualenv --python=python{python_version} {domain}".format(
-            python_version=self.python_version, domain=self.domain
-        )
+        print(snakesay(f"Creating virtualenv with Python{self.python_version}"))
+        command = f"mkvirtualenv --python=python{self.python_version} {self.domain}"
         if nuke:
-            command = "rmvirtualenv {domain} && {command}".format(domain=self.domain, command=command)
-        subprocess.check_call(["bash", "-c", "source virtualenvwrapper.sh && {command}".format(command=command)])
+            command = f"rmvirtualenv {self.domain} && {command}"
+        subprocess.check_call(["bash", "-c", f"source virtualenvwrapper.sh && {command}"])
         return self
 
     def pip_install(self, packages):
-        print(snakesay("Pip installing {packages} (this may take a couple of minutes)".format(packages=packages)))
+        print(snakesay(f"Pip installing {packages} (this may take a couple of minutes)"))
         commands = [str(self.path / "bin/pip"), "install"] + packages.split()
         subprocess.check_call(commands)
